@@ -1,16 +1,16 @@
 use std::env;
 use std::path::PathBuf;
 
-use pdf::file::File;
 use pdf::error::PdfError;
 use pdf::content::*;
+use pdf::file::FileOptions;
 use pdf::object::*;
 use pdf::build::*;
 
 fn main() -> Result<(), PdfError> {
     let path = PathBuf::from(env::args_os().nth(1).expect("no file given"));
     
-    let mut file = File::<Vec<u8>>::open(&path).unwrap();
+    let mut file = FileOptions::cached().open(&path).unwrap();
 
     let mut pages = Vec::new();
     for page in file.pages().take(1) {
