@@ -1,7 +1,7 @@
 use std::env::args;
 
 use pdf::error::PdfError;
-use pdf::file::File;
+use pdf::file::{FileOptions};
 use pdf::object::{FieldDictionary, FieldType, Resolve};
 
 /// extract and print a PDF's metadata
@@ -10,7 +10,7 @@ fn main() -> Result<(), PdfError> {
         .nth(1)
         .expect("Please provide a file path to the PDF you want to explore.");
 
-    let file = File::<Vec<u8>>::open(&path).unwrap();
+    let file = FileOptions::cached().open(&path).unwrap();
     if let Some(ref info) = file.trailer.info_dict {
         info.iter()
             .filter(|(_, primitive)| primitive.to_string_lossy().is_ok())
